<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>排查结果：</span>
                    <el-select class="input-box" v-model="recordData.params.result" placeholder="排查结果" filterable clearable>
                        <el-option v-for="item in resultList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>排查任务状态：</span>
                    <el-select class="input-box" v-model="recordData.params.taskStatus" placeholder="排查任务状态" filterable clearable>
                        <el-option v-for="item in taskStatusList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>任务类型：</span>
                    <el-select class="input-box" v-model="recordData.params.taskType" placeholder="任务类型" filterable clearable>
                        <el-option v-for="item in taskTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>

                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
            </div>
            <el-table :data="recordData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="checkRecordName" label="排查名称" show-overflow-tooltip></el-table-column>
                <el-table-column prop="checkRecordType" label="排查类型" show-overflow-tooltip>
                    <template #default="scope">
                        {{ parseNumber(scope.row.checkRecordType, '排查类型') }}
                    </template>
                </el-table-column>
                <el-table-column prop="riskLevel" label="风险等级" show-overflow-tooltip></el-table-column>
                <el-table-column prop="location" label="区域位置" show-overflow-tooltip></el-table-column>
                <el-table-column prop="status" label="状态" show-overflow-tooltip> </el-table-column>
                <el-table-column prop="createUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="150">
                    <template #default="scope">
                        <el-button size="small" text type="primary" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" @click="onDelrecord(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination
                @size-change="onHandleSizeChange"
                @current-change="onHandleCurrentChange"
                :pager-count="5"
                :page-sizes="[10, 20, 30]"
                v-model:current-page="recordData.params.pageIndex"
                background
                v-model:page-size="recordData.params.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="recordData.total"
                class="page-position"
            >
            </el-pagination>
            <br />
            <br />
        </el-card>
        <recordDialog ref="recordDialogRef" @refreshrecord="initRecordTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import recordDialog from './components/recordDialog.vue';
import { recordApi } from '/@/api/doublePreventSystem/record/index.ts';
import { departmentApi } from '/@/api/department';
import { checkUnitApi } from '/@/api/doublePreventSystem/checkUnit';

// 定义接口来定义对象的类型
interface TableData {
    roleName: string;
    roleSign: string;
    describe: string;
    sort: number;
    status: boolean;
    createTime: string;
}
interface TableDataState {
    recordData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            result: number | null;
            taskStatus: number | null;
            taskType: number | null;
        };
    };
    taskUnitList: [];
    departmentList: Array<DepartmentState>;
    resultList: Array<levelListState>;
    taskStatusList: Array<levelListState>;
    taskTypeList: Array<levelListState>;
}
interface levelListState {
    id: number;
    name: string;
}
interface DepartmentState {}

export default defineComponent({
    name: 'record',
    components: { recordDialog },
    setup() {
        const recordDialogRef = ref();
        const state = reactive<TableDataState>({
            recordData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    result: null,
                    taskStatus: null,
                    taskType: null
                }
            },
            taskUnitList: [],
            departmentList: [],
            resultList: [
                { id: 1, name: '正常' },
                { id: 2, name: '存在隐患' },
                { id: 3, name: '未排查' },
                { id: 4, name: '其他' }
            ],
            taskStatusList: [
                { id: 1, name: '待排查' },
                { id: 2, name: '已完成' },
                { id: 3, name: '超时未排查' },
                { id: 4, name: '排查中' }
            ],
            taskTypeList: [
                { id: 1, name: '周期任务' },
                { id: 2, name: '日常任务' }
            ]
        });
        // 初始化表格数据
        const initRecordTableData = async () => {
            let res = await recordApi().getRecordList(state.recordData.params);
            if (res.data.code === '200') {
                state.recordData.data = res.data.data;
                state.recordData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取部门列表
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const getCheckUnitData = async () => {
            let res = await checkUnitApi().getAllCheckUnitList();
            if (res.data.code === '200') {
                state.taskUnitList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开生产装置弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            recordDialogRef.value.openRecordDialog(type, value, state.departmentList, state.checkRecordTypeList, state.taskUnitList);
        };
        // 删除角色
        const onDelRecord = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除该条生产装置：“${row.produceDeviceName}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await recordApi().deleterecord({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initRecordTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const parseNumber = (value: string | number, type: string) => {};

        const handleSearch = () => {
            initRecordTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.recordData.params.pageSize = val;
            initRecordTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.recordData.params.pageIndex = val;
            initRecordTableData();
        };
        // 页面加载时
        onMounted(() => {
            initRecordTableData();
            getCheckUnitData();
            getDepartmentData();
        });

        return {
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelRecord,
            parseNumber,
            onHandleCurrentChange,
            recordDialog,
            recordDialogRef,
            initRecordTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped></style>
